@@ -4,6 +4,7 @@ from .field import Bool, Int, Int2, Int3, Int4, Float, Float2, Float3, Float4, S
     FileField, JsonField
 from .field_heightfield import HeightFieldField
 from .field_instanced_staticmesh import InstancedStaticMeshField
+from .field_texture import TextureField
 
 from .geo import GeoBase, save_output_file, write_attribs_to_file, add_custom_attributes
 from .geo_heightfield import HeightField, Volume
@@ -16,5 +17,3 @@ from .dispatch import Dispatcher
 from .dson import DsonManager, DsonBase, nextpcgmethod, DsonMetaInfo
 from .dson_create import create_dson_from_pda
 from . import plugin_protocol
-
-# from .dson_pool import DsonPool, DsonTask
\ No newline at end of file
