@@ -10,3 +10,5 @@ dson_outputs_tag = "Outputs"
 dson_output_tag = "output"
 dson_meta_field_tag = "DsonMeta"
 dson_meta_clsname_tag = "clsName"
+dson_meta_if_in_server_tag = "ifInServer"
+dson_meta_plugin_name = "pluginName"
