@@ -57,6 +57,8 @@ def get_outputs(sig: Signature):
     outputs = {}
     return_annotation = sig.return_annotation
     output_index = 0
+    if return_annotation is None:
+        return outputs
     if hasattr(return_annotation, '__origin__') and (return_annotation.__origin__ == tuple or return_annotation.__origin__ == Tuple):
         for ele_type in return_annotation.__args__:
             output_index += 1
